@@ -4,6 +4,7 @@
 {-# LANGUAGE PolyKinds #-}
 {-# LANGUAGE ScopedTypeVariables #-}
 {-# LANGUAGE TypeApplications #-}
+{-# OPTIONS_GHC -Wno-deprecations #-}
 
 -- | Utilities for defining your own validity 'Spec's
 --
@@ -69,6 +70,7 @@ instance Functor Anon where
 -- but it has been copied here for convenience.
 -- https://github.com/hspec/hspec/commit/020c7ecc4a73c24af38e9fab049f60bb9aec6981#diff-29cb22f0ef6e98086a71fc045847bd21L22
 mapSpecTree' :: (SpecTree a -> SpecTree b) -> SpecM a r -> SpecM b r
+
 #if MIN_VERSION_hspec(2,10,0)
 mapSpecTree' f (SpecM specs) = SpecM (mapWriterT (fmap (second (fmap (map f)))) specs)
 #else
@@ -107,7 +109,7 @@ produceResult succesful =
       resultStatus =
         if succesful
           then Success
-          else Failure Nothing $ Reason "Should have failed but didn't."
+          else Failure Nothing $ Test.Hspec.Core.Spec.Reason "Should have failed but didn't."
     }
 
 shouldFail :: Property -> Property
